---
date: 2022-09-01 1:00:00
title: Creeper Adventure
published: True
tags:
  - home
  - meta

---

Creeper adventure is a game I am making with my son.

## Downloads

* [windows](./creeper-windows-latest.zip)
* [linux](./creeper-linux-latest.zip)

## Windows

unzip the file and run creeper.exe.

## Linux

unzip the file.

``` bash
unzip creeper-linux-latest
cd creeper
chmod +x creeper
creeper
```
